from setuptools import setup

setup(name='stlee_test_distr',
      version='0.1',
      description='Gaussian and Binomial distr.',
      packages=['stlee_test_distr'],
      author = 'stlee',
      author_email = 'myemail@testmail.com',
      zip_safe=False)
